=======
Authors
=======

* Ishwar Sawale <ishwar.code@gmail.com>

Thanks
------

* Many, many thanks to David Sandberg
  for creating Facenet and for providing the trained models used in this library.
* Thanks to everyone who works on all the awesome Python data science libraries like numpy, scipy, scikit-image,
  pillow, etc, etc that makes this kind of stuff so easy and fun in Python.
